==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/block/entity/carrier/CarrierBlockEntity.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.block.entity.carrier;

import org.spongepowered.api.block.entity.BlockEntity;
import org.spongepowered.api.data.Keys;
import org.spongepowered.api.data.value.Value;
import org.spongepowered.api.item.inventory.BlockCarrier;
import org.spongepowered.api.item.inventory.type.BlockEntityInventory;

import java.util.Optional;

/**
 * Represents a {@link BlockEntity} that is a carrier of
 * {@link BlockEntityInventory}.
 *
 * <p>Additional information regarding the {@link CarrierBlockEntity} is
 * dependent on the {@link BlockEntity} itself.</p>
 */
public interface CarrierBlockEntity extends BlockEntity, BlockCarrier {

    @Override
    BlockEntityInventory<CarrierBlockEntity> getInventory();

    /**
     * {@link Keys#LOCK_TOKEN}
     *
     * <p>The absence of the value signifies this BlockEntity has no lock.</p>
     *
     * @return The lock token used for opening this {@link BlockEntity}.
     */
    default Optional<Value.Mutable<String>> lockToken() {
        return this.getValue(Keys.LOCK_TOKEN).map(Value::asMutable);
    }
}

==> spongeapi-8.0.0-20210324.005901-379-sources.jar: org/spongepowered/api/block/entity/carrier/CarrierBlockEntity.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.block.entity.carrier;

import org.spongepowered.api.block.entity.BlockEntity;
import org.spongepowered.api.data.Keys;
import org.spongepowered.api.data.value.Value;
import org.spongepowered.api.item.inventory.BlockCarrier;
import org.spongepowered.api.item.inventory.type.BlockEntityInventory;

import java.util.Optional;

/**
 * Represents a {@link BlockEntity} that is a carrier of
 * {@link BlockEntityInventory}.
 *
 * <p>Additional information regarding the {@link CarrierBlockEntity} is
 * dependent on the {@link BlockEntity} itself.</p>
 */
public interface CarrierBlockEntity extends BlockEntity, BlockCarrier {

    @Override
    BlockEntityInventory<CarrierBlockEntity> inventory();

    /**
     * {@link Keys#LOCK_TOKEN}
     *
     * <p>The absence of the value signifies this BlockEntity has no lock.</p>
     *
     * @return The lock token used for opening this {@link BlockEntity}.
     */
    default Optional<Value.Mutable<String>> lockToken() {
        return this.getValue(Keys.LOCK_TOKEN).map(Value::asMutable);
    }
}
